Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/editors/space_sequencer/sequencer_edit.c')
-rw-r--r--source/blender/editors/space_sequencer/sequencer_edit.c10
1 files changed, 8 insertions, 2 deletions
diff --git a/source/blender/editors/space_sequencer/sequencer_edit.c b/source/blender/editors/space_sequencer/sequencer_edit.c
index 1c9b3676b19..b8134095492 100644
--- a/source/blender/editors/space_sequencer/sequencer_edit.c
+++ b/source/blender/editors/space_sequencer/sequencer_edit.c
@@ -153,12 +153,18 @@ static bool sequencer_fcurves_targets_color_strip(const FCurve *fcurve)
}
/*
* Check if there is animation attached to a strip, that is shown on the strip in the UI.
*
* - Colors of color strips are displayed on the strip itself.
+ * - Backdrop is drawn.
*/
-bool ED_space_sequencer_has_visible_animation_on_strip(const struct Scene *scene)
+bool ED_space_sequencer_has_playback_animation(const struct SpaceSeq *sseq,
+ const struct Scene *scene)
{
+ if (sseq->draw_flag & SEQ_DRAW_BACKDROP) {
+ return true;
+ }
+
if (!scene->adt) {
return false;
}
@@ -153,12 +153,18 @@ static bool sequencer_fcurves_targets_color_strip(const FCurve *fcurve)
}
/*
- * Check if there is animation attached to a strip, that is shown on the strip in the UI.
+ * Check if there is animation shown during playback.
*
* - Colors of color strips are displayed on the strip itself.